@@ -22,6 +22,7 @@
  */
 #include <cmath>
 #include <iostream>
+#include <QDebug>
 
 #include <gnuradio/prefs.h>
 #include <gnuradio/top_block.h>
@@ -112,9 +113,9 @@ receiver::receiver(const std::string input_device,
 
     iq_swap = make_iq_swap_cc(false);
     dc_corr = make_dc_corr_cc(d_decim_rate, 1.0);
-    iq_fft = make_rx_fft_c(8192u, d_decim_rate, gr::filter::firdes::WIN_HANN);
+    iq_fft = make_rx_fft_c(8192u, d_decim_rate, gr::fft::window::WIN_HANN);
 
-    audio_fft = make_rx_fft_f(8192u, d_audio_rate, gr::filter::firdes::WIN_HANN);
+    audio_fft = make_rx_fft_f(8192u, d_audio_rate, gr::fft::window::WIN_HANN);
     audio_gain0 = gr::blocks::multiply_const_ff::make(0);
     audio_gain1 = gr::blocks::multiply_const_ff::make(0);
     set_af_gain(DEFAULT_AUDIO_GAIN);
@@ -139,12 +140,9 @@ receiver::receiver(const std::string input_device,
 
     set_demod(RX_DEMOD_NFM);
 
-#ifndef QT_NO_DEBUG_OUTPUT
     gr::prefs pref;
-    std::cout << "Using audio backend: "
-              << pref.get_string("audio", "audio_module", "N/A")
-              << std::endl;
-#endif
+    qDebug() << "Using audio backend:"
+             << pref.get_string("audio", "audio_module", "N/A").c_str();
 }
 
 receiver::~receiver()
@@ -180,11 +178,9 @@ void receiver::stop()
  */
 void receiver::set_input_device(const std::string device)
 {
-#ifndef QT_NO_DEBUG_OUTPUT
-    std::cout << "Set input device:" << std::endl
-              << "  old: " << input_devstr << std::endl
-              << "  new: " << device << std::endl;
-#endif
+    qDebug() << "Set input device:";
+    qDebug() << "  old:" << input_devstr.c_str();
+    qDebug() << "  new:" << device.c_str();
 
     std::string error = "";
 
@@ -216,7 +212,7 @@ void receiver::set_input_device(const std::string device)
     {
         src = osmosdr::source::make(device);
     }
-    catch (std::runtime_error &x)
+    catch (std::exception &x)
     {
         error = x.what();
         src = osmosdr::source::make("file="+get_random_file()+",freq=428e6,rate=96000,repeat=true,throttle=true");
@@ -251,11 +247,9 @@ void receiver::set_input_device(const std::string device)
  */
 void receiver::set_output_device(const std::string device)
 {
-#ifndef QT_NO_DEBUG_OUTPUT
-    std::cout << "Set output device:" << std::endl
-              << "   old: " << output_devstr << std::endl
-              << "   new: " << device << std::endl;
-#endif
+    qDebug() << "Set output device:";
+    qDebug() << "   old:" << output_devstr.c_str();
+    qDebug() << "   new:" << device.c_str();
 
     output_devstr = device;
 
@@ -483,9 +477,7 @@ void receiver::set_dc_cancel(bool enable)
 
     // until we have a way to switch on/off
     // inside the dc_corr_cc we do a reconf
-    rx_demod demod = d_demod;
-    d_demod = RX_DEMOD_OFF;
-    set_demod(demod);
+    set_demod(d_demod, true);
 }
 
 /**
@@ -846,11 +838,11 @@ receiver::status receiver::set_agc_manual_gain(int gain)
     return STATUS_OK; // FIXME
 }
 
-receiver::status receiver::set_demod(rx_demod demod)
+receiver::status receiver::set_demod(rx_demod demod, bool force)
 {
     status ret = STATUS_OK;
 
-    if (demod == d_demod)
+    if (!force && (demod == d_demod))
         return ret;
 
     // tb->lock() seems to hang occasioanlly
@@ -1386,16 +1378,30 @@ void receiver::get_rds_data(std::string &outbuff, int &num)
 
 void receiver::start_rds_decoder(void)
 {
-    stop();
-    rx->start_rds_decoder();
-    start();
+    if (d_running)
+    {
+        stop();
+        rx->start_rds_decoder();
+        start();
+    }
+    else
+    {
+        rx->start_rds_decoder();
+    }
 }
 
 void receiver::stop_rds_decoder(void)
 {
-    stop();
-    rx->stop_rds_decoder();
-    start();
+    if (d_running)
+    {
+        stop();
+        rx->stop_rds_decoder();
+        start();
+    }
+    else
+    {
+        rx->stop_rds_decoder();
+    }
 }
 
 bool receiver::is_rds_decoder_active(void) const
