@@ -23,6 +23,7 @@
 #include <cmath>
 #include <QDebug>
 #include <QDateTime>
+#include <QShortcut>
 #include <QDir>
 #include "dockaudio.h"
 #include "ui_dockaudio.h"
@@ -37,14 +38,6 @@ DockAudio::DockAudio(QWidget *parent) :
 {
     ui->setupUi(this);
 
-#ifdef Q_OS_DARWIN
-    // Workaround for Mac, see http://stackoverflow.com/questions/3978889/why-is-qhboxlayout-causing-widgets-to-overlap
-    // Might be fixed in Qt 5?
-    ui->audioPlayButton->setAttribute(Qt::WA_LayoutUsesWidgetRect);
-    ui->audioRecButton->setAttribute(Qt::WA_LayoutUsesWidgetRect);
-    ui->audioConfButton->setAttribute(Qt::WA_LayoutUsesWidgetRect);
-#endif
-
 #ifdef Q_OS_LINUX
     // buttons can be smaller than 50x32
     ui->audioMuteButton->setMinimumSize(48, 24);
@@ -64,6 +57,8 @@ DockAudio::DockAudio(QWidget *parent) :
     connect(audioOptions, SIGNAL(newUdpPort(int)), this, SLOT(setNewUdpPort(int)));
     connect(audioOptions, SIGNAL(newUdpStereo(bool)), this, SLOT(setNewUdpStereo(bool)));
 
+    connect(ui->audioSpectrum, SIGNAL(pandapterRangeChanged(float,float)), audioOptions, SLOT(setPandapterSliderValues(float,float)));
+
     ui->audioSpectrum->setFreqUnits(1000);
     ui->audioSpectrum->setSampleRate(48000);  // Full bandwidth
     ui->audioSpectrum->setSpanFreq(12000);
@@ -79,6 +74,16 @@ DockAudio::DockAudio(QWidget *parent) :
     ui->audioSpectrum->setVdivDelta(40);
     ui->audioSpectrum->setHdivDelta(40);
     ui->audioSpectrum->setFreqDigits(1);
+
+    QShortcut *rec_toggle_shortcut = new QShortcut(QKeySequence(Qt::Key_R), this);
+    QShortcut *mute_toggle_shortcut = new QShortcut(QKeySequence(Qt::Key_M), this);
+    QShortcut *audio_gain_increase_shortcut1 = new QShortcut(QKeySequence(Qt::Key_Plus), this);
+    QShortcut *audio_gain_decrease_shortcut1 = new QShortcut(QKeySequence(Qt::Key_Minus), this);
+
+    QObject::connect(rec_toggle_shortcut, &QShortcut::activated, this, &DockAudio::recordToggleShortcut);
+    QObject::connect(mute_toggle_shortcut, &QShortcut::activated, this, &DockAudio::muteToggleShortcut);
+    QObject::connect(audio_gain_increase_shortcut1, &QShortcut::activated, this, &DockAudio::increaseAudioGainShortcut);
+    QObject::connect(audio_gain_decrease_shortcut1, &QShortcut::activated, this, &DockAudio::decreaseAudioGainShortcut);
 }
 
 DockAudio::~DockAudio()
@@ -104,6 +109,11 @@ void DockAudio::setNewFftData(float *fftData, int size)
     ui->audioSpectrum->setNewFftData(fftData, size);
 }
 
+void DockAudio::setInvertScrolling(bool enabled)
+{
+    ui->audioSpectrum->setInvertScrolling(enabled);
+}
+
 /*! \brief Set new audio gain.
  *  \param gain the new audio gain in tens of dB (0 dB = 10)
  */
@@ -209,14 +219,17 @@ void DockAudio::on_audioRecButton_clicked(bool checked)
         // use toUTC() function compatible with older versions of Qt.
         QString file_name = QDateTime::currentDateTime().toUTC().toString("gqrx_yyyyMMdd_hhmmss");
         last_audio = QString("%1/%2_%3.wav").arg(rec_dir).arg(file_name).arg(rx_freq);
+        QFileInfo info(last_audio);
 
         // emit signal and start timer
         emit audioRecStarted(last_audio);
 
+        ui->audioRecLabel->setText(info.fileName());
         ui->audioRecButton->setToolTip(tr("Stop audio recorder"));
         ui->audioPlayButton->setEnabled(false); /* prevent playback while recording */
     }
     else {
+        ui->audioRecLabel->setText("<i>DSP</i>");
         ui->audioRecButton->setToolTip(tr("Start audio recorder"));
         emit audioRecStopped();
 
@@ -349,6 +362,11 @@ void DockAudio::saveSettings(QSettings *settings)
     else
         settings->remove("waterfall_max_db");
 
+    if (audioOptions->getLockButtonState())
+        settings->setValue("db_ranges_locked", true);
+    else
+        settings->remove("db_ranges_locked");
+
     if (rec_dir != QDir::homePath())
         settings->setValue("rec_dir", rec_dir);
     else
@@ -374,7 +392,7 @@ void DockAudio::saveSettings(QSettings *settings)
 
 void DockAudio::readSettings(QSettings *settings)
 {
-    int     ival, fft_min, fft_max;
+    int     bool_val, ival, fft_min, fft_max;
     bool    conv_ok = false;
 
     if (!settings)
@@ -406,6 +424,9 @@ void DockAudio::readSettings(QSettings *settings)
         fft_max = 0;
     audioOptions->setWaterfallRange(fft_min, fft_max);
 
+    bool_val = settings->value("db_ranges_locked", false).toBool();
+    audioOptions->setLockButtonState(bool_val);
+
     // Location of audio recordings
     rec_dir = settings->value("rec_dir", QDir::homePath()).toString();
     audioOptions->setRecDir(rec_dir);
@@ -462,3 +483,19 @@ void DockAudio::setNewUdpStereo(bool enabled)
 {
     udp_stereo = enabled;
 }
+
+void DockAudio::recordToggleShortcut() {
+    ui->audioRecButton->click();
+}
+
+void DockAudio::muteToggleShortcut() {
+    ui->audioMuteButton->click();
+}
+
+void DockAudio::increaseAudioGainShortcut() {
+	ui->audioGainSlider->triggerAction(QSlider::SliderPageStepAdd);
+}
+
+void DockAudio::decreaseAudioGainShortcut() {
+	ui->audioGainSlider->triggerAction(QSlider::SliderPageStepSub);
+}
