@@ -349,7 +349,9 @@ void CFreqCtrl::updateCtrl(bool all)
 void CFreqCtrl::resizeEvent(QResizeEvent *)
 {
 // qDebug() <<rect.width() << rect.height();
-    m_Pixmap = QPixmap(size()); // resize pixmap to current control size
+    int dpr = devicePixelRatio();
+    m_Pixmap = QPixmap(width() * dpr, height() * dpr); // resize pixmap to current control size
+    m_Pixmap.setDevicePixelRatio(dpr);
     m_Pixmap.fill(m_BkColor);
     m_UpdateAll = true;
     updateCtrl(true);
@@ -857,10 +859,10 @@ void CFreqCtrl::setFrequencyFocus()
     uint8_t position = floor(log10(m_freq));
     position = (uint8_t)fmax(position, 4);      // restrict min to 100s of kHz
 
-    QMouseEvent *mouseEvent = new QMouseEvent(QEvent::MouseMove,
-                                              m_DigitInfo[position].dQRect.center(),
-                                              Qt::NoButton,
-                                              Qt::NoButton,
-                                              Qt::NoModifier);
-    mouseMoveEvent(mouseEvent);
+    QMouseEvent mouseEvent(QEvent::MouseMove,
+                           m_DigitInfo[position].dQRect.center(),
+                           Qt::NoButton,
+                           Qt::NoButton,
+                           Qt::NoModifier);
+    mouseMoveEvent(&mouseEvent);
 }
