@@ -28,7 +28,6 @@
  * or implied, of Moe Wheatley.
  */
 #include <cmath>
-#include <math.h>
 #include <QColor>
 #include <QDateTime>
 #include <QDebug>
@@ -41,8 +40,7 @@
 #include "bookmarks.h"
 #include "dxc_spots.h"
 
-// Comment out to enable plotter debug messages
-//#define PLOTTER_DEBUG
+Q_LOGGING_CATEGORY(plotter, "plotter")
 
 #define CUR_CUT_DELTA 5		//cursor capture delta in pixels
 
@@ -166,17 +164,16 @@ CPlotter::CPlotter(QWidget *parent) : QFrame(parent)
 }
 
 CPlotter::~CPlotter()
-{
-}
+= default;
 
 QSize CPlotter::minimumSizeHint() const
 {
-    return QSize(50, 50);
+    return {50, 50};
 }
 
 QSize CPlotter::sizeHint() const
 {
-    return QSize(180, 180);
+    return {180, 180};
 }
 
 void CPlotter::mouseMoveEvent(QMouseEvent* event)
@@ -184,8 +181,8 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
 
     QPoint pt = event->pos();
 
-    /* mouse ent er / mouse leave events */
-    if (m_OverlayPixmap.rect().contains(pt))
+    /* mouse enter / mouse leave events */
+    if (pt.y() < m_OverlayPixmap.height() / m_DPR)
     {
         //is in Overlay bitmap region
         if (event->buttons() == Qt::NoButton)
@@ -272,13 +269,13 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
                     qint64 hoverFrequency = freqFromX(pt.x());
                     QString toolTipText = QString("F: %1 kHz").arg(hoverFrequency/1.e3f, 0, 'f', 3);
                     QFontMetrics metrics(m_Font);
-                    int bandTopY = m_OverlayPixmap.height() - metrics.height() - 2 * VER_MARGIN - m_BandPlanHeight;
+                    int bandTopY = (m_OverlayPixmap.height() / m_DPR) - metrics.height() - 2 * VER_MARGIN - m_BandPlanHeight;
                     QList<BandInfo> hoverBands = BandPlan::Get().getBandsEncompassing(hoverFrequency);
-                    if(m_BandPlanEnabled && pt.y() > bandTopY && hoverBands.size() > 0)
+                    if(m_BandPlanEnabled && pt.y() > bandTopY && !hoverBands.empty())
                     {
                         toolTipText.append("\n");
-                        for (int i = 0; i < hoverBands.size(); i++)
-                            toolTipText.append("\n" + hoverBands[i].name);
+                        for (auto & hoverBand : hoverBands)
+                            toolTipText.append("\n" + hoverBand.name);
                     }
                     QToolTip::showText(event->globalPos(), toolTipText, this);
                 }
@@ -318,7 +315,7 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
             // move Y scale up/down
             float delta_px = m_Yzero - pt.y();
             float delta_db = delta_px * fabs(m_PandMindB - m_PandMaxdB) /
-                             (float)m_OverlayPixmap.height();
+                             (float)(m_OverlayPixmap.height() / m_DPR);
             m_PandMindB -= delta_db;
             m_PandMaxdB -= delta_db;
             if (out_of_range(m_PandMindB, m_PandMaxdB))
@@ -348,12 +345,12 @@ void CPlotter::mouseMoveEvent(QMouseEvent* event)
             setCursor(QCursor(Qt::ClosedHandCursor));
             // pan viewable range or move center frequency
             int delta_px = m_Xzero - pt.x();
-            qint64 delta_hz = delta_px * m_Span / m_OverlayPixmap.width();
+            qint64 delta_hz = delta_px * m_Span / (m_OverlayPixmap.width() / m_DPR);
             if (event->buttons() & Qt::MidButton)
             {
                 m_CenterFreq += delta_hz;
                 m_DemodCenterFreq += delta_hz;
-                emit newCenterFreq(m_CenterFreq);
+                emit newDemodFreq(m_DemodCenterFreq, m_DemodCenterFreq - m_CenterFreq);
             }
             else
             {
@@ -586,11 +583,11 @@ bool CPlotter::saveWaterfall(const QString & filename) const
         painter.drawText(rect, Qt::AlignRight|Qt::AlignVCenter, tt.toString("hh:mm:ss"));
     }
 
-    return pixmap.save(filename, 0, -1);
+    return pixmap.save(filename, nullptr, -1);
 }
 
 /** Get waterfall time resolution in milleconds / line. */
-quint64 CPlotter::getWfTimeRes(void)
+quint64 CPlotter::getWfTimeRes() const
 {
     if (msec_per_wfline)
         return msec_per_wfline;
@@ -656,7 +653,6 @@ void CPlotter::mousePressEvent(QMouseEvent * event)
                 // set center freq
                 m_CenterFreq = roundFreq(freqFromX(pt.x()), m_ClickResolution);
                 m_DemodCenterFreq = m_CenterFreq;
-                emit newCenterFreq(m_CenterFreq);
                 emit newDemodFreq(m_DemodCenterFreq, m_DemodCenterFreq - m_CenterFreq);
                 drawOverlay();
             }
@@ -683,11 +679,11 @@ void CPlotter::mousePressEvent(QMouseEvent * event)
         }
         else if (m_CursorCaptured == TAG)
         {
-            for (int i = 0; i < m_Taglist.size(); i++)
+            for (auto & tag : m_Taglist)
             {
-                if (m_Taglist[i].first.contains(event->pos()))
+                if (tag.first.contains(event->pos()))
                 {
-                    m_DemodCenterFreq = m_Taglist[i].second;
+                    m_DemodCenterFreq = tag.second;
                     emit newDemodFreq(m_DemodCenterFreq, m_DemodCenterFreq - m_CenterFreq);
                     break;
                 }
@@ -700,7 +696,7 @@ void CPlotter::mouseReleaseEvent(QMouseEvent * event)
 {
     QPoint pt = event->pos();
 
-    if (!m_OverlayPixmap.rect().contains(pt))
+    if (pt.y() >= m_OverlayPixmap.height() / m_DPR)
     {
         // not in Overlay region
         if (NOCAP != m_CursorCaptured)
@@ -745,14 +741,14 @@ void CPlotter::zoomStepX(float step, int x)
         f_max = m_CenterFreq + m_SampleFreq / 2.f;
     new_range = f_max - f_min;
 
-    qint64 fc = (qint64)(f_min + (f_max - f_min) / 2.0);
+    auto fc = (qint64)(f_min + (f_max - f_min) / 2.0);
 
     setFftCenterFreq(fc - m_CenterFreq);
     setSpanFreq((quint32)new_range);
 
     float factor = (float)m_SampleFreq / (float)m_Span;
     emit newZoomLevel(factor);
-    qDebug() << QString("Spectrum zoom: %1x").arg(factor, 0, 'f', 1);
+    qCDebug(plotter) << QString("Spectrum zoom: %1x").arg(factor, 0, 'f', 1);
 
     m_PeakHoldValid = false;
 }
@@ -779,9 +775,9 @@ void CPlotter::wheelEvent(QWheelEvent * event)
         // Vertical zoom. Wheel down: zoom out, wheel up: zoom in
         // During zoom we try to keep the point (dB or kHz) under the cursor fixed
         float zoom_fac = delta < 0 ? 1.1 : 0.9;
-        float ratio = (float)pt.y() / (float)m_OverlayPixmap.height();
+        float ratio = (float)pt.y() / (float)(m_OverlayPixmap.height() / m_DPR);
         float db_range = m_PandMaxdB - m_PandMindB;
-        float y_range = (float)m_OverlayPixmap.height();
+        auto y_range = (float)(m_OverlayPixmap.height() / m_DPR);
         float db_per_pix = db_range / y_range;
         float fixed_db = m_PandMaxdB - pt.y() * db_per_pix;
 
@@ -839,10 +835,13 @@ void CPlotter::resizeEvent(QResizeEvent* )
         int     fft_plot_height;
 
         m_Size = size();
+        m_DPR = devicePixelRatio();
         fft_plot_height = m_Percent2DScreen * m_Size.height() / 100;
-        m_OverlayPixmap = QPixmap(m_Size.width(), fft_plot_height);
+        m_OverlayPixmap = QPixmap(m_Size.width() * m_DPR, fft_plot_height * m_DPR);
+        m_OverlayPixmap.setDevicePixelRatio(m_DPR);
         m_OverlayPixmap.fill(Qt::black);
-        m_2DPixmap = QPixmap(m_Size.width(), fft_plot_height);
+        m_2DPixmap = QPixmap(m_Size.width() * m_DPR, fft_plot_height * m_DPR);
+        m_2DPixmap.setDevicePixelRatio(m_DPR);
         m_2DPixmap.fill(Qt::black);
 
         int height = m_Size.height() - fft_plot_height;
@@ -893,7 +892,7 @@ void CPlotter::draw()
         m_DrawOverlay = false;
     }
 
-    QPoint LineBuf[MAX_SCREENSIZE];
+    QPointF LineBuf[MAX_SCREENSIZE];
 
     if (!m_Running)
         return;
@@ -968,20 +967,16 @@ void CPlotter::draw()
     }
 
     // get/draw the 2D spectrum
-    w = m_2DPixmap.width();
-    h = m_2DPixmap.height();
+    w = m_2DPixmap.width() / m_DPR;
+    h = m_2DPixmap.height() / m_DPR;
 
     if (w != 0 && h != 0)
     {
         // first copy into 2Dbitmap the overlay bitmap.
-        m_2DPixmap = m_OverlayPixmap.copy(0,0,w,h);
+        m_2DPixmap = m_OverlayPixmap.copy(m_OverlayPixmap.rect());
 
         QPainter painter2(&m_2DPixmap);
 
-        // workaround for "fixed" line drawing since Qt 5
-        // see http://stackoverflow.com/questions/16990326
-        painter2.translate(0.5, 0.5);
-
         // get new scaled fft data
         getScreenIntegerFFTData(h, qMin(w, MAX_SCREENSIZE),
                                 m_PandMaxdB, m_PandMindB,
@@ -995,10 +990,10 @@ void CPlotter::draw()
         n = xmax - xmin;
         for (i = 0; i < n; i++)
         {
-            LineBuf[i].setX(i + xmin);
-            LineBuf[i].setY(m_fftbuf[i + xmin]);
+            LineBuf[i].setX(i + xmin + 0.5);
+            LineBuf[i].setY(m_fftbuf[i + xmin] + 0.5);
             if (m_FftFill)
-                painter2.fillRect(i + xmin, m_fftbuf[i + xmin], 1, h, fillBrush);
+                painter2.fillRect(i + xmin, m_fftbuf[i + xmin] + 1, 1, h, fillBrush);
         }
 
         painter2.setPen(m_FftColor);
@@ -1113,7 +1108,7 @@ void CPlotter::getScreenIntegerFFTData(qint32 plotHeight, qint32 plotWidth,
                                        float maxdB, float mindB,
                                        qint64 startFreq, qint64 stopFreq,
                                        float *inBuf, qint32 *outBuf,
-                                       int *xmin, int *xmax)
+                                       int *xmin, int *xmax) const
 {
     qint32 i;
     qint32 y;
@@ -1125,7 +1120,7 @@ void CPlotter::getScreenIntegerFFTData(qint32 plotHeight, qint32 plotWidth,
     qint32 m_FFTSize = m_fftDataSize;
     float *m_pFFTAveBuf = inBuf;
     float  dBGainFactor = ((float)plotHeight) / fabs(maxdB - mindB);
-    qint32* m_pTranslateTbl = new qint32[qMax(m_FFTSize, plotWidth)];
+    auto* m_pTranslateTbl = new qint32[qMax(m_FFTSize, plotWidth)];
 
     /** FIXME: qint64 -> qint32 **/
     m_BinMin = (qint32)((float)startFreq * (float)m_FFTSize / m_SampleFreq);
@@ -1246,8 +1241,8 @@ void CPlotter::drawOverlay()
     if (m_OverlayPixmap.isNull())
         return;
 
-    int     w = m_OverlayPixmap.width();
-    int     h = m_OverlayPixmap.height();
+    int     w = m_OverlayPixmap.width() / m_DPR;
+    int     h = m_OverlayPixmap.height() / m_DPR;
     int     x,y;
     float   pixperdiv;
     float   adjoffset;
@@ -1266,7 +1261,7 @@ void CPlotter::drawOverlay()
     QList<BookmarkInfo> tags;
 
     // X and Y axis areas
-    m_YAxisWidth = metrics.boundingRect("XXXX").width() + 2 * HOR_MARGIN;
+    m_YAxisWidth = metrics.boundingRect("-120").width() + 2 * HOR_MARGIN;
     m_XAxisYCenter = h - metrics.height()/2;
     int xAxisHeight = metrics.height() + 2 * VER_MARGIN;
     int xAxisTop = h - xAxisHeight;
@@ -1305,10 +1300,10 @@ void CPlotter::drawOverlay()
             std::stable_sort(tags.begin(),tags.end());
         }
         QVector<int> tagEnd(nLevels + 1);
-        for (int i = 0; i < tags.size(); i++)
+        for (auto & tag : tags)
         {
-            x = xFromFreq(tags[i].frequency);
-            int nameWidth = fm.boundingRect(tags[i].name).width();
+            x = xFromFreq(tag.frequency);
+            int nameWidth = fm.boundingRect(tag.name).width();
 
             int level = 0;
             while(level < nLevels && tagEnd[level] > x)
@@ -1327,9 +1322,9 @@ void CPlotter::drawOverlay()
             const auto levelNHeightBottom = levelNHeight + fontHeight;
             const auto levelNHeightBottomSlant = levelNHeightBottom + slant;
 
-            m_Taglist.append(qMakePair<QRect, qint64>(QRect(x, levelNHeight, nameWidth + slant, fontHeight), tags[i].frequency));
+            m_Taglist.append(qMakePair<QRect, qint64>(QRect(x, levelNHeight, nameWidth + slant, fontHeight), tag.frequency));
 
-            QColor color = QColor(tags[i].GetColor());
+            QColor color = QColor(tag.GetColor());
             color.setAlpha(0x60);
             // Vertical line
             painter.setPen(QPen(color, 1, Qt::DashLine));
@@ -1348,7 +1343,7 @@ void CPlotter::drawOverlay()
             painter.setPen(QPen(color, 2, Qt::SolidLine));
             painter.drawText(x + slant, levelNHeight, nameWidth,
                              fontHeight, Qt::AlignVCenter | Qt::AlignHCenter,
-                             tags[i].name);
+                             tag.name);
         }
     }
 
@@ -1357,14 +1352,14 @@ void CPlotter::drawOverlay()
         QList<BandInfo> bands = BandPlan::Get().getBandsInRange(m_CenterFreq + m_FftCenter - m_Span / 2,
                                                                 m_CenterFreq + m_FftCenter + m_Span / 2);
 
-        for (int i = 0; i < bands.size(); i++)
+        for (auto & band : bands)
         {
-            int band_left = xFromFreq(bands[i].minFrequency);
-            int band_right = xFromFreq(bands[i].maxFrequency);
+            int band_left = xFromFreq(band.minFrequency);
+            int band_right = xFromFreq(band.maxFrequency);
             int band_width = band_right - band_left;
             rect.setRect(band_left, xAxisTop - m_BandPlanHeight, band_width, m_BandPlanHeight);
-            painter.fillRect(rect, bands[i].color);
-            QString band_label = bands[i].name + " (" + bands[i].modulation + ")";
+            painter.fillRect(rect, band.color);
+            QString band_label = band.name + " (" + band.modulation + ")";
             int textWidth = metrics.boundingRect(band_label).width();
             if (band_left < w && band_width > textWidth + 20)
             {
@@ -1432,11 +1427,9 @@ void CPlotter::drawOverlay()
     pixperdiv = (float) h * (float) dbstepsize / (m_PandMaxdB - m_PandMindB);
     adjoffset = (float) h * (mindbadj - m_PandMindB) / (m_PandMaxdB - m_PandMindB);
 
-#ifdef PLOTTER_DEBUG
-    qDebug() << "minDb =" << m_PandMindB << "maxDb =" << m_PandMaxdB
-             << "mindbadj =" << mindbadj << "dbstepsize =" << dbstepsize
-             << "pixperdiv =" << pixperdiv << "adjoffset =" << adjoffset;
-#endif
+    qCDebug(plotter) << "minDb =" << m_PandMindB << "maxDb =" << m_PandMaxdB
+                     << "mindbadj =" << mindbadj << "dbstepsize =" << dbstepsize
+                     << "pixperdiv =" << pixperdiv << "adjoffset =" << adjoffset;
 
     painter.setPen(QPen(QColor(PLOTTER_GRID_COLOR), 1, Qt::DotLine));
     for (int i = 0; i <= m_VerDivs; i++)
@@ -1447,8 +1440,6 @@ void CPlotter::drawOverlay()
     }
 
     // draw amplitude values (y axis)
-    int dB = m_PandMaxdB;
-    m_YAxisWidth = metrics.boundingRect("-120 ").width();
     painter.setPen(QColor(PLOTTER_TEXT_COLOR));
     for (int i = 0; i < m_VerDivs; i++)
     {
@@ -1456,8 +1447,8 @@ void CPlotter::drawOverlay()
         int th = metrics.height();
         if (y < h -xAxisHeight)
         {
-            dB = mindbadj + dbstepsize * i;
-            rect.setRect(HOR_MARGIN, y - th / 2, m_YAxisWidth, th);
+            int dB = mindbadj + dbstepsize * i;
+            rect.setRect(HOR_MARGIN, y - th / 2, m_YAxisWidth - 2 * HOR_MARGIN, th);
             painter.drawText(rect, Qt::AlignRight|Qt::AlignVCenter, QString::number(dB));
         }
     }
@@ -1484,7 +1475,7 @@ void CPlotter::drawOverlay()
     {
         // if not running so is no data updates to draw to screen
         // copy into 2Dbitmap the overlay bitmap.
-        m_2DPixmap = m_OverlayPixmap.copy(0,0,w,h);
+        m_2DPixmap = m_OverlayPixmap.copy(m_OverlayPixmap.rect());
 
         // trigger a new paintEvent
         update();
@@ -1506,7 +1497,7 @@ void CPlotter::makeFrequencyStrs()
     if ((1 == m_FreqUnits) || (m_FreqDigits == 0))
     {
         // if units is Hz then just output integer freq
-        for (int i = 0; i <= m_HorDivs; i++)
+        for (i = 0; i <= m_HorDivs; i++)
         {
             freq = (float)StartFreq/(float)m_FreqUnits;
             m_HDivText[i].setNum((int)freq);
@@ -1516,7 +1507,7 @@ void CPlotter::makeFrequencyStrs()
     }
     // here if is fractional frequency values
     // so create max sized text based on frequency units
-    for (int i = 0; i <= m_HorDivs; i++)
+    for (i = 0; i <= m_HorDivs; i++)
     {
         freq = (float)StartFreq / (float)m_FreqUnits;
         m_HDivText[i].setNum(freq,'f', m_FreqDigits);
@@ -1573,10 +1564,10 @@ qint64 CPlotter::freqFromX(int x)
 quint64 CPlotter::msecFromY(int y)
 {
     // ensure we are in the waterfall region
-    if (y < m_OverlayPixmap.height())
+    if (y < m_OverlayPixmap.height() / m_DPR)
         return 0;
 
-    int dy = y - m_OverlayPixmap.height();
+    int dy = y - m_OverlayPixmap.height() / m_DPR;
 
     if (msec_per_wfline > 0)
         return tlast_wf_ms - dy * msec_per_wfline;
@@ -1654,7 +1645,7 @@ void CPlotter::resetHorizontalZoom(void)
 }
 
 /** Center FFT plot around 0 (corresponds to center freq). */
-void CPlotter::moveToCenterFreq(void)
+void CPlotter::moveToCenterFreq()
 {
     setFftCenterFreq(0);
     updateOverlay();
@@ -1662,7 +1653,7 @@ void CPlotter::moveToCenterFreq(void)
 }
 
 /** Center FFT plot around the demodulator frequency. */
-void CPlotter::moveToDemodFreq(void)
+void CPlotter::moveToDemodFreq()
 {
     setFftCenterFreq(m_DemodCenterFreq-m_CenterFreq);
     updateOverlay();
@@ -1671,7 +1662,7 @@ void CPlotter::moveToDemodFreq(void)
 }
 
 /** Set FFT plot color. */
-void CPlotter::setFftPlotColor(const QColor color)
+void CPlotter::setFftPlotColor(const QColor& color)
 {
     m_FftColor = color;
     m_FftFillCol = color;
@@ -1714,11 +1705,9 @@ void CPlotter::toggleBandPlan(bool state)
 
 void CPlotter::calcDivSize (qint64 low, qint64 high, int divswanted, qint64 &adjlow, qint64 &step, int& divs)
 {
-#ifdef PLOTTER_DEBUG
-    qDebug() << "low: " << low;
-    qDebug() << "high: " << high;
-    qDebug() << "divswanted: " << divswanted;
-#endif
+    qCDebug(plotter) << "low:" << low;
+    qCDebug(plotter) << "high:" << high;
+    qCDebug(plotter) << "divswanted:" << divswanted;
 
     if (divswanted == 0)
         return;
@@ -1746,11 +1735,9 @@ void CPlotter::calcDivSize (qint64 low, qint64 high, int divswanted, qint64 &adj
     if (adjlow < low)
         adjlow += step;
 
-#ifdef PLOTTER_DEBUG
-    qDebug() << "adjlow: "  << adjlow;
-    qDebug() << "step: " << step;
-    qDebug() << "divs: " << divs;
-#endif
+    qCDebug(plotter) << "adjlow:" << adjlow;
+    qCDebug(plotter) << "step:" << step;
+    qCDebug(plotter) << "divs:" << divs;
 }
 
 // contributed by Chris Kuethe @ckuethe
@@ -2170,7 +2157,7 @@ void CPlotter::setWfColormap(const QString &cmap)
         // contributed by @drmpeg @devnulling
         // for use with high quality spectrum paining
         // see https://gist.github.com/drmpeg/31a9a7dd6918856aeb60
-        for (int i = 0; i < 256; i++)
+        for (i = 0; i < 256; i++)
         {
             if (i < 64)
             {
